@@ -12,9 +12,9 @@ class Postgres:
         self.slot = slot
 
     def run_cmd(self, cmd):
-        execute_sync(f'psql -h {self.host} -p {self.port} -U {self.username} {cmd}',
+        execute_sync(f'psql -h {self.host} -p {self.port} -U {self.username} -c {cmd}',
                      env=[('PGPASSWORD', self.password)])
 
     def force_switch_wal(self):
-        command = 'select * from pg_switch_xlog()' if self.version < 10 else 'select * from pg_switch_wal()'
-        execute_sync(command)
+        pg_command = 'select * from pg_switch_xlog()' if float(self.version) < 10 else 'select * from pg_switch_wal()'
+        self.run_cmd(pg_command)
